
import { DataTypes, Model, Optional , Sequelize} from "sequelize";

interface CheckInAttributes {
  id: string;
  checkin: Date;
  checkout: Date;
  clientID: string;
  boatID: string;
  destination: string;
  note: string;
}
export interface CheckInAttributesInput
  extends Optional<CheckInAttributes, "id"> { }

  class CheckIn extends Model<CheckInAttributes, CheckInAttributesInput> implements CheckInAttributes {
  declare id: string;
  declare checkin: Date;
  declare checkout: Date;
  declare clientID: string;
  declare boatID: string;
  declare destination: string;
  declare note: string;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initCheckIn = async (sequelizeConnection: Sequelize) => {
  CheckIn.init(
    {
      id: {
        type: DataTypes.UUID,
        defaultValue: DataTypes.UUIDV4,
        primaryKey: true,
        allowNull: false,
      },
      checkin: {
        type: DataTypes.DATE,
        allowNull: false,
      },
      checkout: {
        type: DataTypes.DATE,
        allowNull: false,
      },
      clientID: {
        type: DataTypes.UUID,
        references: {
          model: "customer",
          key: "id",
        },
      },
      boatID: {
        type: DataTypes.UUID,
        references: {
          model: "boat",
          key: "id",
        },
      },
      destination: {
        type: new DataTypes.STRING(),
      },
      note: {
        type: new DataTypes.STRING(),
      },
    },
    {
      tableName: "checkin",
      sequelize: sequelizeConnection,
    }
    );
}

export default CheckIn;
